==> beast-privilege-api-2.6.6-20230316.071008-7-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialCustomPersonVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class KeyMemberMemorialCustomPersonVO implements Serializable {
    private Integer id;
    private Integer memorialId;
    private String cellPhone;
    private String customName;
    private Date customDate;
    private Integer isRepeatEveryYear;
    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getMemorialId() {
        return memorialId;
    }

    public void setMemorialId(Integer memorialId) {
        this.memorialId = memorialId;
    }

    public String getCellPhone() {
        return cellPhone;
    }

    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }

    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }

    public Date getCustomDate() {
        return customDate;
    }

    public void setCustomDate(Date customDate) {
        this.customDate = customDate;
    }

    public Integer getIsRepeatEveryYear() {
        return isRepeatEveryYear;
    }

    public void setIsRepeatEveryYear(Integer isRepeatEveryYear) {
        this.isRepeatEveryYear = isRepeatEveryYear;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }
}

==> beast-privilege-api-3.0.15-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialCustomPersonVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class KeyMemberMemorialCustomPersonVO implements Serializable {
    private Integer id;
    private Integer memorialId;
    private String cellPhone;
    private String customName;
    private Date customDate;
    private Integer isRepeatEveryYear;

    private String customDateMonthday;

    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getMemorialId() {
        return memorialId;
    }

    public void setMemorialId(Integer memorialId) {
        this.memorialId = memorialId;
    }

    public String getCellPhone() {
        return cellPhone;
    }

    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }

    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }

    public Date getCustomDate() {
        return customDate;
    }

    public void setCustomDate(Date customDate) {
        this.customDate = customDate;
    }

    public Integer getIsRepeatEveryYear() {
        return isRepeatEveryYear;
    }

    public void setIsRepeatEveryYear(Integer isRepeatEveryYear) {
        this.isRepeatEveryYear = isRepeatEveryYear;
    }

    public String getCustomDateMonthday() {
        return customDateMonthday;
    }

    public void setCustomDateMonthday(String customDateMonthday) {
        this.customDateMonthday = customDateMonthday;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }
}
